@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Moose;
 
@@ -138,7 +138,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.012
+Version 0.013
 
 =head1 SYNOPSIS
 
@@ -505,8 +505,13 @@ L<Test::CleanNamespaces|Test::CleanNamespaces> author test.
 =cut
 
     $file{q{xt/author/clean-namespaces.t}} = $test_header . <<'XT_AUTHOR_CLEAN_NAMESPACES_T';
+use Test::More;
 use Test::CleanNamespaces;
 
+if ( !Test::CleanNamespaces->find_modules() ) {
+    plan skip_all => 'No files found to test.';
+}
+
 all_namespaces_clean();
 XT_AUTHOR_CLEAN_NAMESPACES_T
 
